pub struct Channel {
pub activation_token: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub crypto_key_name: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub provider: Option<String>,
pub pubsub_topic: Option<String>,
pub satisfies_pzs: Option<bool>,
pub state: Option<String>,
pub uid: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A representation of the Channel resource. A Channel is a resource on which event providers publish their events. The published events are delivered through the transport associated with the channel. Note that a channel is associated with exactly one event provider.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations channels create projects (request)
- locations channels get projects (response)
- locations channels patch projects (request)
Fields
activation_token: Option<String>Output only. The activation token for the channel. The token must be used by the provider to register the channel for publishing.
create_time: Option<DateTime<Utc>>Output only. The creation time.
crypto_key_name: Option<String>Optional. Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt their event data. It must match the pattern projects/*/locations/*/keyRings/*/cryptoKeys/*.
labels: Option<HashMap<String, String>>Optional. Resource labels.
name: Option<String>Required. The resource name of the channel. Must be unique within the location on the project and must be in projects/{project}/locations/{location}/channels/{channel_id} format.
provider: Option<String>The name of the event provider (e.g. Eventarc SaaS partner) associated with the channel. This provider will be granted permissions to publish events to the channel. Format: projects/{project}/locations/{location}/providers/{provider_id}.
pubsub_topic: Option<String>Output only. The name of the Pub/Sub topic created and managed by Eventarc system as a transport for the event delivery. Format: projects/{project}/topics/{topic_id}.
satisfies_pzs: Option<bool>Output only. Whether or not this Channel satisfies the requirements of physical zone separation
state: Option<String>Output only. The state of a Channel.
uid: Option<String>Output only. Server assigned unique identifier for the channel. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted.
update_time: Option<DateTime<Utc>>Output only. The last-modified time.