pub struct Destination {
pub cloud_function: Option<String>,
pub cloud_run: Option<CloudRun>,
pub gke: Option<GKE>,
pub http_endpoint: Option<HttpEndpoint>,
pub network_config: Option<NetworkConfig>,
pub workflow: Option<String>,
}Expand description
Represents a target of an invocation over HTTP.
This type is not used in any activity, and only used as part of another schema.
Fields
cloud_function: Option<String>The Cloud Function resource name. Cloud Functions V1 and V2 are supported. Format: projects/{project}/locations/{location}/functions/{function} This is a read-only field. Creating Cloud Functions V1/V2 triggers is only supported via the Cloud Functions product. An error will be returned if the user sets this value.
cloud_run: Option<CloudRun>Cloud Run fully-managed resource that receives the events. The resource should be in the same project as the trigger.
gke: Option<GKE>A GKE service capable of receiving events. The service should be running in the same project as the trigger.
http_endpoint: Option<HttpEndpoint>An HTTP endpoint destination described by an URI.
network_config: Option<NetworkConfig>Optional. Network config is used to configure how Eventarc resolves and connect to a destination. This should only be used with HttpEndpoint destination type.
workflow: Option<String>The resource name of the Workflow whose Executions are triggered by the events. The Workflow resource should be deployed in the same project as the trigger. Format: projects/{project}/locations/{location}/workflows/{workflow}