pub struct EventType {
pub description: Option<String>,
pub event_schema_uri: Option<String>,
pub filtering_attributes: Option<Vec<FilteringAttribute>>,
pub type_: Option<String>,
}Expand description
A representation of the event type resource.
This type is not used in any activity, and only used as part of another schema.
Fields
description: Option<String>Output only. Human friendly description of what the event type is about. For example “Bucket created in Cloud Storage”.
event_schema_uri: Option<String>Output only. URI for the event schema. For example “https://github.com/googleapis/google-cloudevents/blob/master/proto/google/events/cloud/storage/v1/events.proto”
filtering_attributes: Option<Vec<FilteringAttribute>>Output only. Filtering attributes for the event type.
type_: Option<String>Output only. The full name of the event type (for example, “google.cloud.storage.object.v1.finalized”). In the form of {provider-specific-prefix}.{resource}.{version}.{verb}. Types MUST be versioned and event schemas are guaranteed to remain backward compatible within one version. Note that event type versions and API versions do not need to match.