pub struct FilteringAttribute {
pub attribute: Option<String>,
pub description: Option<String>,
pub path_pattern_supported: Option<bool>,
pub required: Option<bool>,
}Expand description
A representation of the FilteringAttribute resource. Filtering attributes are per event type.
This type is not used in any activity, and only used as part of another schema.
Fields
attribute: Option<String>Output only. Attribute used for filtering the event type.
description: Option<String>Output only. Description of the purpose of the attribute.
path_pattern_supported: Option<bool>Output only. If true, the attribute accepts matching expressions in the Eventarc PathPattern format.
required: Option<bool>Output only. If true, the triggers for this provider should always specify a filter on these attributes. Trigger creation will fail otherwise.