GoogleCloudEventarcV1PipelineDestination

Struct GoogleCloudEventarcV1PipelineDestination 

pub struct GoogleCloudEventarcV1PipelineDestination {
    pub authentication_config: Option<GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig>,
    pub http_endpoint: Option<GoogleCloudEventarcV1PipelineDestinationHttpEndpoint>,
    pub message_bus: Option<String>,
    pub network_config: Option<GoogleCloudEventarcV1PipelineDestinationNetworkConfig>,
    pub output_payload_format: Option<GoogleCloudEventarcV1PipelineMessagePayloadFormat>,
    pub topic: Option<String>,
    pub workflow: Option<String>,
}
Represents a target of an invocation over HTTP.

This type is not used in any activity, and only used as part of another schema.

Fields

authentication_config: Option<GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig>

Optional. An authentication config used to authenticate message requests, such that destinations can verify the source. For example, this can be used with private Google Cloud destinations that require Google Cloud credentials for access like Cloud Run. This field is optional and should be set only by users interested in authenticated push.

http_endpoint: Option<GoogleCloudEventarcV1PipelineDestinationHttpEndpoint>

Optional. An HTTP endpoint destination described by an URI. If a DNS FQDN is provided as the endpoint, Pipeline will create a peering zone to the consumer VPC and forward DNS requests to the VPC specified by network config to resolve the service endpoint. See: https://cloud.google.com/dns/docs/zones/zones-overview#peering_zones

message_bus: Option<String>

Optional. The resource name of the Message Bus to which events should be published. The Message Bus resource should exist in the same project as the Pipeline. Format: projects/{project}/locations/{location}/messageBuses/{message_bus}

network_config: Option<GoogleCloudEventarcV1PipelineDestinationNetworkConfig>

Optional. Network config is used to configure how Pipeline resolves and connects to a destination.

output_payload_format: Option<GoogleCloudEventarcV1PipelineMessagePayloadFormat>

Optional. The message format before it is delivered to the destination. If not set, the message will be delivered in the format it was originally delivered to the Pipeline. This field can only be set if Pipeline.input_payload_format is also set.

topic: Option<String>

Optional. The resource name of the Pub/Sub topic to which events should be published. Format: projects/{project}/locations/{location}/topics/{topic}

workflow: Option<String>

Optional. The resource name of the Workflow whose Executions are triggered by the events. The Workflow resource should be deployed in the same project as the Pipeline. Format: projects/{project}/locations/{location}/workflows/{workflow}