pub struct GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig {
pub google_oidc: Option<GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken>,
pub oauth_token: Option<GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOAuthToken>,
}Expand description
Represents a config used to authenticate message requests.
This type is not used in any activity, and only used as part of another schema.
Fields
google_oidc: Option<GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken>Optional. This authenticate method will apply Google OIDC tokens signed by a Google Cloud service account to the requests.
oauth_token: Option<GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOAuthToken>Optional. If specified, an OAuth token will be generated and attached as an Authorization header in the HTTP request. This type of authorization should generally only be used when calling Google APIs hosted on *.googleapis.com.