pub struct GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOAuthToken {
pub scope: Option<String>,
pub service_account: Option<String>,
}Expand description
Contains information needed for generating an OAuth token. This type of authorization should generally only be used when calling Google APIs hosted on *.googleapis.com.
This type is not used in any activity, and only used as part of another schema.
Fields
scope: Option<String>Optional. OAuth scope to be used for generating OAuth access token. If not specified, “https://www.googleapis.com/auth/cloud-platform” will be used.
service_account: Option<String>Required. Service account email used to generate the OAuth token. The principal who calls this API must have iam.serviceAccounts.actAs permission in the service account. See https://cloud.google.com/iam/docs/understanding-service-accounts for more information. Eventarc service agents must have roles/roles/iam.serviceAccountTokenCreator role to allow Pipeline to create OAuth2 tokens for authenticated requests.