GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken

Struct GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken 

pub struct GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken {
    pub audience: Option<String>,
    pub service_account: Option<String>,
}
Represents a config used to authenticate with a Google OIDC token using a Google Cloud service account. Use this authentication method to invoke your Cloud Run and Cloud Functions destinations or HTTP endpoints that support Google OIDC.

This type is not used in any activity, and only used as part of another schema.

Fields

audience: Option<String>

Optional. Audience to be used to generate the OIDC Token. The audience claim identifies the recipient that the JWT is intended for. If unspecified, the destination URI will be used.

service_account: Option<String>

Required. Service account email used to generate the OIDC Token. The principal who calls this API must have iam.serviceAccounts.actAs permission in the service account. See https://cloud.google.com/iam/docs/understanding-service-accounts for more information. Eventarc service agents must have roles/roles/iam.serviceAccountTokenCreator role to allow the Pipeline to create OpenID tokens for authenticated requests.