pub struct GoogleCloudEventarcV1PipelineDestinationNetworkConfig {
pub network_attachment: Option<String>,
}Expand description
Represents a network config to be used for destination resolution and connectivity.
This type is not used in any activity, and only used as part of another schema.
Fields
network_attachment: Option<String>Required. Name of the NetworkAttachment that allows access to the consumer VPC. Format: projects/{PROJECT_ID}/regions/{REGION}/networkAttachments/{NETWORK_ATTACHMENT_NAME}