pub struct HttpEndpoint {
pub uri: Option<String>,
}Expand description
Represents a HTTP endpoint destination.
This type is not used in any activity, and only used as part of another schema.
Fields
uri: Option<String>Required. The URI of the HTTP endpoint. The value must be a RFC2396 URI string. Examples: http://10.10.10.8:80/route, http://svc.us-central1.p.local:8080/. Only HTTP and HTTPS protocols are supported. The host can be either a static IP addressable from the VPC specified by the network config, or an internal DNS hostname of the service resolvable via Cloud DNS.