pub struct ListChannelConnectionsResponse {
pub channel_connections: Option<Vec<ChannelConnection>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
The response message for the ListChannelConnections method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations channel connections list projects (response)
Fields
channel_connections: Option<Vec<ChannelConnection>>The requested channel connections, up to the number specified in page_size.
next_page_token: Option<String>A page token that can be sent to ListChannelConnections to request the next page. If this is empty, then there are no more pages.
unreachable: Option<Vec<String>>Unreachable resources, if any.