pub struct ListChannelsResponse {
pub channels: Option<Vec<Channel>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
The response message for the ListChannels method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations channels list projects (response)
Fields
channels: Option<Vec<Channel>>The requested channels, up to the number specified in page_size.
next_page_token: Option<String>A page token that can be sent to ListChannels to request the next page. If this is empty, then there are no more pages.
unreachable: Option<Vec<String>>Unreachable resources, if any.