pub struct ListGoogleApiSourcesResponse {
pub google_api_sources: Option<Vec<GoogleApiSource>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
The response message for the ListGoogleApiSources method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations google api sources list projects (response)
Fields
google_api_sources: Option<Vec<GoogleApiSource>>The requested GoogleApiSources, up to the number specified in page_size.
next_page_token: Option<String>A page token that can be sent to ListMessageBusEnrollments to request the next page. If this is empty, then there are no more pages.
unreachable: Option<Vec<String>>Unreachable resources, if any.