pub struct ListProvidersResponse {
pub next_page_token: Option<String>,
pub providers: Option<Vec<Provider>>,
pub unreachable: Option<Vec<String>>,
}Expand description
The response message for the ListProviders method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations providers list projects (response)
Fields
next_page_token: Option<String>A page token that can be sent to ListProviders to request the next page. If this is empty, then there are no more pages.
providers: Option<Vec<Provider>>The requested providers, up to the number specified in page_size.
unreachable: Option<Vec<String>>Unreachable resources, if any.