pub struct ListTriggersResponse {
pub next_page_token: Option<String>,
pub triggers: Option<Vec<Trigger>>,
pub unreachable: Option<Vec<String>>,
}Expand description
The response message for the ListTriggers method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations triggers list projects (response)
Fields
next_page_token: Option<String>A page token that can be sent to ListTriggers to request the next page. If this is empty, then there are no more pages.
triggers: Option<Vec<Trigger>>The requested triggers, up to the number specified in page_size.
unreachable: Option<Vec<String>>Unreachable resources, if any.