pub struct NetworkConfig {
pub network_attachment: Option<String>,
}Expand description
Network Configuration that can be inherited by other protos.
This type is not used in any activity, and only used as part of another schema.
Fields
network_attachment: Option<String>Required. Name of the NetworkAttachment that allows access to the customer’s VPC. Format: projects/{PROJECT_ID}/regions/{REGION}/networkAttachments/{NETWORK_ATTACHMENT_NAME}