pub struct Provider {
pub display_name: Option<String>,
pub event_types: Option<Vec<EventType>>,
pub name: Option<String>,
}Expand description
A representation of the Provider resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations providers get projects (response)
Fields
display_name: Option<String>Output only. Human friendly name for the Provider. For example “Cloud Storage”.
event_types: Option<Vec<EventType>>Output only. Event types for this provider.
name: Option<String>Output only. In projects/{project}/locations/{location}/providers/{provider_id} format.