pub struct RetryPolicy {
pub max_attempts: Option<i32>,
}Expand description
The retry policy configuration for the Trigger. Can only be set with Cloud Run destinations.
This type is not used in any activity, and only used as part of another schema.
Fields
max_attempts: Option<i32>Optional. The maximum number of delivery attempts for any message. The only valid value is 1.