pub struct Transport {
pub pubsub: Option<Pubsub>,
}Expand description
Represents the transport intermediaries created for the trigger to deliver events.
This type is not used in any activity, and only used as part of another schema.
Fields
pubsub: Option<Pubsub>The Pub/Sub topic and subscription used by Eventarc as a transport intermediary.