pub struct Pipeline {Show 15 fields
pub annotations: Option<HashMap<String, String>>,
pub create_time: Option<DateTime<Utc>>,
pub crypto_key_name: Option<String>,
pub destinations: Option<Vec<GoogleCloudEventarcV1PipelineDestination>>,
pub display_name: Option<String>,
pub etag: Option<String>,
pub input_payload_format: Option<GoogleCloudEventarcV1PipelineMessagePayloadFormat>,
pub labels: Option<HashMap<String, String>>,
pub logging_config: Option<LoggingConfig>,
pub mediations: Option<Vec<GoogleCloudEventarcV1PipelineMediation>>,
pub name: Option<String>,
pub retry_policy: Option<GoogleCloudEventarcV1PipelineRetryPolicy>,
pub satisfies_pzs: Option<bool>,
pub uid: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A representation of the Pipeline resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations pipelines create projects (request)
- locations pipelines get projects (response)
- locations pipelines patch projects (request)
Fields
annotations: Option<HashMap<String, String>>Optional. User-defined annotations. See https://google.aip.dev/128#annotations.
create_time: Option<DateTime<Utc>>Output only. The creation time. A timestamp in RFC3339 UTC “Zulu” format, with nanosecond resolution and up to nine fractional digits. Examples: “2014-10-02T15:01:23Z” and “2014-10-02T15:01:23.045123456Z”.
crypto_key_name: Option<String>Optional. Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt the event data. If not set, an internal Google-owned key will be used to encrypt messages. It must match the pattern “projects/{project}/locations/{location}/keyRings/{keyring}/cryptoKeys/{key}”.
destinations: Option<Vec<GoogleCloudEventarcV1PipelineDestination>>Required. List of destinations to which messages will be forwarded. Currently, exactly one destination is supported per Pipeline.
display_name: Option<String>Optional. Display name of resource.
etag: Option<String>Output only. This checksum is computed by the server based on the value of other fields, and might be sent only on create requests to ensure that the client has an up-to-date value before proceeding.
input_payload_format: Option<GoogleCloudEventarcV1PipelineMessagePayloadFormat>Optional. The payload format expected for the messages received by the Pipeline. If input_payload_format is set then any messages not matching this format will be treated as persistent errors. If input_payload_format is not set, then the message data will be treated as an opaque binary and no output format can be set on the Pipeline through the Pipeline.Destination.output_payload_format field. Any Mediations on the Pipeline that involve access to the data field will fail as persistent errors.
labels: Option<HashMap<String, String>>Optional. User labels attached to the Pipeline that can be used to group resources. An object containing a list of “key”: value pairs. Example: { “name”: “wrench”, “mass”: “1.3kg”, “count”: “3” }.
logging_config: Option<LoggingConfig>Optional. Config to control Platform Logging for Pipelines.
mediations: Option<Vec<GoogleCloudEventarcV1PipelineMediation>>Optional. List of mediation operations to be performed on the message. Currently, only one Transformation operation is allowed in each Pipeline.
name: Option<String>Identifier. The resource name of the Pipeline. Must be unique within the location of the project and must be in projects/{project}/locations/{location}/pipelines/{pipeline} format.
retry_policy: Option<GoogleCloudEventarcV1PipelineRetryPolicy>Optional. The retry policy to use in the pipeline.
satisfies_pzs: Option<bool>Output only. Whether or not this Pipeline satisfies the requirements of physical zone separation
uid: Option<String>Output only. Server-assigned unique identifier for the Pipeline. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted.
update_time: Option<DateTime<Utc>>Output only. The last-modified time. A timestamp in RFC3339 UTC “Zulu” format, with nanosecond resolution and up to nine fractional digits. Examples: “2014-10-02T15:01:23Z” and “2014-10-02T15:01:23.045123456Z”.